#
# spec file for package ghc-hspec
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hspec
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.5.4
Release:        1.2
Summary:        A Testing Framework for Haskell
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-call-stack-devel
BuildRequires:  ghc-hspec-core-devel
BuildRequires:  ghc-hspec-discover-devel
BuildRequires:  ghc-hspec-expectations-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-hspec-meta-devel
BuildRequires:  ghc-stringbuilder-devel
%endif

%description
Hspec is a testing framework for Haskell. It is inspired by the Ruby library
RSpec. Some of Hspec's distinctive features are:

* a friendly DSL for defining tests

* integration with QuickCheck, SmallCheck, and HUnit

* parallel test execution

* automatic discovery of test files

The Hspec Manual is at <http://hspec.github.io/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.markdown

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update hspec to version 2.5.4.
  [#]# Changes in 2.5.4
  - Show how to rerun individual spec items on test failures (see #205)
  [#]# Changes in 2.5.3
  - Treat character escapes like `\NUL` as single tokens on `--diff` (see #351)
  - Allow a `/` at the beginning and at the end of an absolute path that is
    passed to `--match` or `--skip`
  [#]# Changes in 2.5.2
  - Use module:line:column as default label for describe/it (see #250)
  - Warn if user is affected by https://ghc.haskell.org/trac/ghc/ticket/13285 (see #329)
  [#]# Changes in 2.5.1
  - Disable tests for Test.Hspec.Core.Timer (see #352)
  [#]# Changes in 2.5.0
  - Add `sequential` (see #311)
  - Add support for `--diff` when `shouldBe` is uesd with
    `QuickCheck`-properties
  - Add source locations when `shouldBe` is uesd with `QuickCheck` properties
  - Print `QuickCheck` labels on success (see #297)
  - Retain output of `verbose`, `label`, `collect`, `classify`, etc. for
    `QuickCheck` properties (see #257)
  - Extract source location from error / undefined (see #316)
* Fri Mar 16 2018 psimons@suse.com
- Update hspec to version 2.5.0.
  A more detailed change log is not available.
* Wed Mar 14 2018 psimons@suse.com
- Update hspec to version 2.4.8.
  A more detailed change log is not available.
